@@ -52,6 +52,18 @@ pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod octo_print_backup;
 pub use self::octo_print_backup::OctoPrintBackup;
+pub mod octo_print_event;
+pub use self::octo_print_event::OctoPrintEvent;
+pub mod octo_print_event_event_name_enum;
+pub use self::octo_print_event_event_name_enum::OctoPrintEventEventNameEnum;
+pub mod octo_print_event_model_enum;
+pub use self::octo_print_event_model_enum::OctoPrintEventModelEnum;
+pub mod octo_print_event_request;
+pub use self::octo_print_event_request::OctoPrintEventRequest;
+pub mod octo_print_install;
+pub use self::octo_print_install::OctoPrintInstall;
+pub mod octo_print_install_request;
+pub use self::octo_print_install_request::OctoPrintInstallRequest;
 pub mod octo_print_settings;
 pub use self::octo_print_settings::OctoPrintSettings;
 pub mod octo_print_settings_request;
@@ -78,6 +90,8 @@ pub mod paginated_janus_stream_list;
 pub use self::paginated_janus_stream_list::PaginatedJanusStreamList;
 pub mod paginated_octo_print_backup_list;
 pub use self::paginated_octo_print_backup_list::PaginatedOctoPrintBackupList;
+pub mod paginated_octo_print_install_list;
+pub use self::paginated_octo_print_install_list::PaginatedOctoPrintInstallList;
 pub mod paginated_octo_print_settings_list;
 pub use self::paginated_octo_print_settings_list::PaginatedOctoPrintSettingsList;
 pub mod paginated_octo_printer_profile_list;
@@ -104,6 +118,8 @@ pub mod patched_janus_cloud_stream_request;
 pub use self::patched_janus_cloud_stream_request::PatchedJanusCloudStreamRequest;
 pub mod patched_janus_edge_stream_request;
 pub use self::patched_janus_edge_stream_request::PatchedJanusEdgeStreamRequest;
+pub mod patched_octo_print_install_request;
+pub use self::patched_octo_print_install_request::PatchedOctoPrintInstallRequest;
 pub mod patched_octo_print_settings_request;
 pub use self::patched_octo_print_settings_request::PatchedOctoPrintSettingsRequest;
 pub mod patched_octo_printer_profile_request;
